"use strict";

exports.__esModule = true;
/**
 * @module 1-liners/minus
 * 
 * @description
 *
 * Same as `a - b`
 * 
 * @example
 * 
 * 	var minus = require('1-liners/minus');
 * 
 * 	minus(3, 2); // => 1
 * 
 */

exports["default"] = function (a, b) {
  return a - b;
};

module.exports = exports["default"];