"use strict";

exports.__esModule = true;
/**
 * @module 1-liners/dec
 * 
 * @description
 *
 * Same as `a - 1`
 * 
 * @example
 * 
 * 	var dec = require('1-liners/dec');
 * 
 * 	dec(1); // => 0
 * 
 */

exports["default"] = function (val) {
  return val - 1;
};

module.exports = exports["default"];