"use strict";

exports.__esModule = true;
/**
 * @module 1-liners/noop
 * 
 * @description
 *
 * Same as `function(){}`.
 * 
 * @example
 * 
 * 	var noop = require('1-liners/noop');
 * 
 * 	window.console = {
 * 			log: noop,
 * 			error: noop,
 * 			warn: noop,
 * 			table: noop
 * 	};
 * 
 */

exports["default"] = function () {};

module.exports = exports["default"];