"use strict";

exports.__esModule = true;
/**
 * @module 1-liners/by
 * 
 * @description
 *
 * Same as `a / b`
 * 
 * @example
 * 
 * 	var by = require('1-liners/by');
 * 
 * 	by(6, 2); // => 3
 * 
 */

exports["default"] = function (a, b) {
  return a / b;
};

module.exports = exports["default"];