/**
 * @module 1-liners/not
 * 
 * @description
 *
 * Same as `!a`.
 * 
 * @example
 * 
 * 	var not = require('1-liners/not');
 * 
 * 	not(true); // => false
 * 	not(false); // => true
 * 
 */
export default (a) => !a;
